@@ -1,20 +1,21 @@
 """Lookup routines."""
 
-import re
 import logging
+import re
 from collections import namedtuple
+from ipaddress import IPv4Address
 
-import pytricia
 import dns.resolver
 import dns.reversename
+import pytricia
+from defang import refang
 
 from .exceptions import (
+    AddressFormatError,
     NoASDataError,
     NonroutableAddressError,
-    AddressFormatError,
 )
 
-
 logger = logging.getLogger(__name__)
 
 AS_SERVICES = {
@@ -76,13 +77,27 @@ ASData = namedtuple(
 
 
 def validate_ipv4(addr):
-    """Validate that input is an IPv4 address."""
+    """
+    Validate IP addresses.
+
+    - Validate that input is a valid IPv4 address
+    - Flag various reserved and non-routable addresses
+
+    """
     # Check that it's a valid IPv4 address
-    if not re.match(IPV4_FMT, addr):
+    # if not re.match(IPV4_FMT, addr):
+    #    raise AddressFormatError("Invalid format for IPv4 address")
+    # for octet in addr.split("."):
+    #    if not 0 <= int(octet) <= 255:
+    #        raise AddressFormatError("Invalid octet value for IPv4 address")
+    # Distinguish address family by IPv4 vs. IPv6 separator
+    if "." not in addr:
         raise AddressFormatError("Invalid format for IPv4 address")
-    for octet in addr.split("."):
-        if not 0 <= int(octet) <= 255:
-            raise AddressFormatError("Invalid octet value for IPv4 address")
+
+    try:
+        IPv4Address(addr)
+    except ValueError as e:
+        raise AddressFormatError(f"Invalid IPv4 address: {e}")
 
     # Verify address not in reserved/non-routable prefixes.
     if addr in pyt:
@@ -107,7 +122,7 @@ def get_cymru_data(s, extra={}):
     # Cymru results began to append a comma and country code to the end of the
     # AS name, polluting the data. Strip it off.
     s = re.sub(r", [A-Z]{2}$", "", s)
-    fields = s.split(" | ")
+    fields = s.split("|")
     fields = [x.strip() for x in fields]
     as_data = ASData(
         asn=fields[0],
@@ -138,7 +153,7 @@ def get_shadowserver_data(s):
     # Shadowserver results at one point appended a comma and country code to
     # the end of the AS name, polluting the data. Strip it off.
     s = re.sub(r", [A-Z]{2}$", "", s)
-    fields = s.split(" | ")
+    fields = s.split("|")
     fields = [x.strip() for x in fields]
     # For any response that returned AS data but no AS name, alert user.
     if fields[0] and not fields[2]:
@@ -175,7 +190,10 @@ def get_as_data(addr, service="shadowserver"):
     address. In these cases, an appropriate exception is raised.
 
     """
+    # Remove leading or trailing whitespace and/or defanging of input
     addr = addr.strip()
+    addr = refang(addr)
+
     try:
         validate_ipv4(addr)
     except AddressFormatError:
